@@ -26,7 +26,7 @@
 
 #define	BUFFER_LEN		1024
 
-static void reset_test (char *converter_name, int converter) ;
+static void reset_test (int converter) ;
 
 int
 main (void)
@@ -35,9 +35,9 @@ main (void)
 
 	puts ("") ;
 
-	reset_test ("Zero Order Hold interpolator", SRC_ZERO_ORDER_HOLD) ;
-	reset_test ("Linear interpolator", SRC_LINEAR) ;
-	reset_test ("Sinc interpolator", SRC_SINC_FASTEST) ;
+	reset_test (SRC_ZERO_ORDER_HOLD) ;
+	reset_test (SRC_LINEAR) ;
+	reset_test (SRC_SINC_FASTEST) ;
 
 	puts ("") ;
 
@@ -45,7 +45,7 @@ main (void)
 } /* main */
 
 static void
-reset_test (char *converter_name, int converter)
+reset_test (int converter)
 {	static float data_one [BUFFER_LEN] ;
 	static float data_zero [BUFFER_LEN] ;
 	static float output [BUFFER_LEN] ;
@@ -54,7 +54,7 @@ reset_test (char *converter_name, int converter)
 	SRC_DATA src_data ;
 	int k, error ;
 
-	printf ("\treset_test (%-28s) ....... ", converter_name) ;
+	printf ("\treset_test (%-28s) ....... ", src_get_name (converter)) ;
 	fflush (stdout) ;
 
 	for (k = 0 ; k < BUFFER_LEN ; k++)
@@ -91,7 +91,7 @@ reset_test (char *converter_name, int converter)
 	src_data.output_frames	= BUFFER_LEN ;
 	src_data.src_ratio		= 0.9 ;
 	src_data.end_of_input	= 1 ;
-
+	
 	if ((error = src_process (src_state, &src_data)) != 0)
 	{	printf ("\n\nLine %d : src_simple () returned error : %s\n\n", __LINE__, src_strerror (error)) ;
 		exit (1) ;
@@ -104,6 +104,9 @@ reset_test (char *converter_name, int converter)
 			exit (1) ;
 			} ;
 
+	/* Make sure that this function has been exported. */
+	src_set_ratio (src_state, 1.0) ;
+
 	/* Delete converter. */
 	src_state = src_delete (src_state) ;
 
