@@ -21,3 +21,7 @@ void gen_windowed_sines (float *data, int data_len, double *freqs, int freq_coun
 void save_oct_data (char *filename, float *input, int in_len, float *output, int out_len) ;
 
 void force_efence_banner (void) ;
+
+void interleave_data (const float *in, float *out, int frames, int channels) ;
+
+void deinterleave_data (const float *in, float *out, int frames, int channels) ;
